@@ -10,7 +10,7 @@ def test_movie_summary_should_be_some_text_with_author(ia):
         if plot.endswith('redcommander27'):
             sel_plot = plot
             break
-    assert re.match(r'^Thomas A. Anderson is a man.*As a rebel.*::redcommander27$', sel_plot)
+    assert re.match(r'^Thomas A. Anderson is a man.*As a rebel.*redcommander27$', sel_plot)
 
 
 def test_movie_summary_if_none_should_be_excluded(ia):
